==> open-xchange-mobile-api-facade_1.2.7.orig.tar.bz2: open-xchange-mobile-api-facade-1.2.7/com.openexchange.mobile.api.facade/src/com/openexchange/mobile/api/facade/connectors/impl/ValidateAccountConnector.java <==
/*
 *
 *    OPEN-XCHANGE legal information
 *
 *    All intellectual property rights in the Software are protected by
 *    international copyright laws.
 *
 *
 *    In some countries OX, OX Open-Xchange, open xchange and OXtender
 *    as well as the corresponding Logos OX Open-Xchange and OX are registered
 *    trademarks of the OX Software GmbH group of companies.
 *    The use of the Logos is not covered by the GNU General Public License.
 *    Instead, you are allowed to use these Logos according to the terms and
 *    conditions of the Creative Commons License, Version 2.5, Attribution,
 *    Non-commercial, ShareAlike, and the interpretation of the term
 *    Non-commercial applicable to the aforementioned license is published
 *    on the web site http://www.open-xchange.com/EN/legal/index.html.
 *
 *    Please make sure that third-party modules and libraries are used
 *    according to their respective licenses.
 *
 *    Any modifications to this package must retain all copyright notices
 *    of the original copyright holder(s) for the original code used.
 *
 *    After any such modifications, the original and derivative code shall remain
 *    under the copyright of the copyright holder(s) and/or original author(s)per
 *    the Attribution and Assignment Agreement that can be located at
 *    http://www.open-xchange.com/EN/developer/. The contributing author shall be
 *    given Attribution for the derivative code and a license granting use.
 *
 *     Copyright (C) 2016-2020 OX Software GmbH
 *     Mail: info@open-xchange.com
 *
 *
 *     This program is free software; you can redistribute it and/or modify it
 *     under the terms of the GNU General Public License, Version 2 as published
 *     by the Free Software Foundation.
 *
 *     This program is distributed in the hope that it will be useful, but
 *     WITHOUT ANY WARRANTY; without even the implied warranty of MERCHANTABILITY
 *     or FITNESS FOR A PARTICULAR PURPOSE. See the GNU General Public License
 *     for more details.
 *
 *     You should have received a copy of the GNU General Public License along
 *     with this program; if not, write to the Free Software Foundation, Inc., 59
 *     Temple Place, Suite 330, Boston, MA 02111-1307 USA
 *
 */

package com.openexchange.mobile.api.facade.connectors.impl;

import java.nio.charset.Charset;

import com.fasterxml.jackson.databind.ObjectMapper;
import com.openexchange.mobile.api.facade.auth.SessionData;
import com.openexchange.mobile.api.facade.connectors.BaseConnector;
import com.openexchange.mobile.api.facade.connectors.RequestConfiguration;
import com.openexchange.mobile.api.facade.connectors.requests.mtos.MailAccountDataMto;
import com.openexchange.mobile.api.facade.connectors.responses.BooleanResponseMto;
import com.openexchange.mobile.api.facade.models.MailAccountData;
import com.openexchange.mobile.api.facade.utils.JacksonUtil;

import lombok.SneakyThrows;

import org.apache.http.HttpEntity;
import org.apache.http.client.methods.HttpUriRequest;
import org.apache.http.client.methods.RequestBuilder;
import org.apache.http.entity.StringEntity;

public class ValidateAccountConnector extends BaseConnector<BooleanResponseMto> {

    private static final String CODE_INSECURE_CONNECTION = "MSG-0079";

    private final MailAccountDataMto accountData;

    private final boolean forceInsecureConnection;

    public ValidateAccountConnector(RequestConfiguration configuration, SessionData sessionData, MailAccountData account, boolean forceInsecureConnection) {
        super(configuration, sessionData, "account", BooleanResponseMto.class);
        this.accountData = new MailAccountDataMto(account);
        this.forceInsecureConnection = forceInsecureConnection;
    }

    @Override
    protected HttpUriRequest createRequest() {
        RequestBuilder builder = RequestBuilder.put(createUrl());
        builder.setCharset(Charset.forName("UTF-8"));
        addSessionData(builder);
        builder.addParameter("action", "validate");
        builder.setEntity(createEntity());
        return builder.build();
    }

    @SneakyThrows
    private HttpEntity createEntity() {
        ObjectMapper mapper = JacksonUtil.getMapper();
        String str = mapper.writeValueAsString(accountData);
        return new StringEntity(str, "UTF-8");
    }

    @Override
    protected boolean isError(BooleanResponseMto responseBody) {
        if (responseBody != null && forceInsecureConnection && CODE_INSECURE_CONNECTION.equals(responseBody.getCode())) {
            return false;
        }
        return super.isError(responseBody);
    }

    public static boolean map(BooleanResponseMto response) {
        if (response == null) {
            return false;
        }
        Boolean data = response.getData();
        return data != null && data.booleanValue();
    }

}

==> open-xchange-mobile-api-facade_1.2.12.orig.tar.bz2: open-xchange-mobile-api-facade-1.2.12/com.openexchange.mobile.api.facade/src/com/openexchange/mobile/api/facade/connectors/impl/ValidateAccountConnector.java <==
/*
 *
 *    OPEN-XCHANGE legal information
 *
 *    All intellectual property rights in the Software are protected by
 *    international copyright laws.
 *
 *
 *    In some countries OX, OX Open-Xchange, open xchange and OXtender
 *    as well as the corresponding Logos OX Open-Xchange and OX are registered
 *    trademarks of the OX Software GmbH group of companies.
 *    The use of the Logos is not covered by the GNU General Public License.
 *    Instead, you are allowed to use these Logos according to the terms and
 *    conditions of the Creative Commons License, Version 2.5, Attribution,
 *    Non-commercial, ShareAlike, and the interpretation of the term
 *    Non-commercial applicable to the aforementioned license is published
 *    on the web site http://www.open-xchange.com/EN/legal/index.html.
 *
 *    Please make sure that third-party modules and libraries are used
 *    according to their respective licenses.
 *
 *    Any modifications to this package must retain all copyright notices
 *    of the original copyright holder(s) for the original code used.
 *
 *    After any such modifications, the original and derivative code shall remain
 *    under the copyright of the copyright holder(s) and/or original author(s)per
 *    the Attribution and Assignment Agreement that can be located at
 *    http://www.open-xchange.com/EN/developer/. The contributing author shall be
 *    given Attribution for the derivative code and a license granting use.
 *
 *     Copyright (C) 2016-2020 OX Software GmbH
 *     Mail: info@open-xchange.com
 *
 *
 *     This program is free software; you can redistribute it and/or modify it
 *     under the terms of the GNU General Public License, Version 2 as published
 *     by the Free Software Foundation.
 *
 *     This program is distributed in the hope that it will be useful, but
 *     WITHOUT ANY WARRANTY; without even the implied warranty of MERCHANTABILITY
 *     or FITNESS FOR A PARTICULAR PURPOSE. See the GNU General Public License
 *     for more details.
 *
 *     You should have received a copy of the GNU General Public License along
 *     with this program; if not, write to the Free Software Foundation, Inc., 59
 *     Temple Place, Suite 330, Boston, MA 02111-1307 USA
 *
 */

package com.openexchange.mobile.api.facade.connectors.impl;

import java.nio.charset.Charset;

import com.fasterxml.jackson.databind.ObjectMapper;
import com.openexchange.mobile.api.facade.auth.SessionData;
import com.openexchange.mobile.api.facade.connectors.BaseConnector;
import com.openexchange.mobile.api.facade.connectors.RequestConfiguration;
import com.openexchange.mobile.api.facade.connectors.requests.mtos.MailAccountDataMto;
import com.openexchange.mobile.api.facade.connectors.responses.BooleanResponseMto;
import com.openexchange.mobile.api.facade.models.MailAccountData;
import com.openexchange.mobile.api.facade.utils.JacksonUtil;

import lombok.SneakyThrows;

import org.apache.http.HttpEntity;
import org.apache.http.client.methods.HttpUriRequest;
import org.apache.http.client.methods.RequestBuilder;
import org.apache.http.entity.StringEntity;

public class ValidateAccountConnector extends BaseConnector<BooleanResponseMto> {

    private static final String CODE_INSECURE_CONNECTION = "MSG-0079";

    private final MailAccountDataMto accountData;

    private final boolean forceInsecureConnection;

    private final boolean ignoreInvalidTransport;

    public ValidateAccountConnector(RequestConfiguration configuration, SessionData sessionData, MailAccountData account, boolean forceInsecureConnection, boolean ignoreInvalidTransport) {
        super(configuration, sessionData, "account", BooleanResponseMto.class);
        this.accountData = new MailAccountDataMto(account);
        this.forceInsecureConnection = forceInsecureConnection;
        this.ignoreInvalidTransport = ignoreInvalidTransport;
    }

    @Override
    protected HttpUriRequest createRequest() {
        RequestBuilder builder = RequestBuilder.put(createUrl());
        builder.setCharset(Charset.forName("UTF-8"));
        addSessionData(builder);
        builder.addParameter("action", "validate");
        if (ignoreInvalidTransport) {
            builder.addParameter("ignoreInvalidTransport", "true");
        }
        builder.setEntity(createEntity());
        return builder.build();
    }

    @SneakyThrows
    private HttpEntity createEntity() {
        ObjectMapper mapper = JacksonUtil.getMapper();
        String str = mapper.writeValueAsString(accountData);
        return new StringEntity(str, "UTF-8");
    }

    @Override
    protected boolean isError(BooleanResponseMto responseBody) {
        if (responseBody != null && forceInsecureConnection && CODE_INSECURE_CONNECTION.equals(responseBody.getCode())) {
            return false;
        }
        return super.isError(responseBody);
    }

    public static boolean map(BooleanResponseMto response) {
        if (response == null) {
            return false;
        }
        Boolean data = response.getData();
        return data != null && data.booleanValue();
    }

}
